==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/TextCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { TextCellInfoDescription } from "./TextCellInfoDescription";
/**
 * @hidden
 */
export let TextCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class TextCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (TextCellInfoDescriptionMetadata.a == null) {
                TextCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TextCellInfoDescriptionMetadata.c(TextCellInfoDescriptionMetadata.a);
            }
            if (a.k(TextCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.ab(TextCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
            a.item("TextValue", "String");
        }
        static d(a) {
            TextCellInfoDescriptionMetadata.b(a);
            a.ad("TextCellInfo", () => new TextCellInfoDescription());
            a.ac("TextCellInfo", TextCellInfoDescriptionMetadata.a);
        }
    }
    TextCellInfoDescriptionMetadata.$t = markType(TextCellInfoDescriptionMetadata, 'TextCellInfoDescriptionMetadata');
    TextCellInfoDescriptionMetadata.a = null;
    return TextCellInfoDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/TextCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { TextCellInfoDescription } from "./TextCellInfoDescription";
/**
 * @hidden
 */
export let TextCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class TextCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (TextCellInfoDescriptionMetadata.a == null) {
                TextCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TextCellInfoDescriptionMetadata.c(TextCellInfoDescriptionMetadata.a);
            }
            if (a.k(TextCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.ac(TextCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
            a.item("TextValue", "String");
        }
        static d(a) {
            TextCellInfoDescriptionMetadata.b(a);
            a.ae("TextCellInfo", () => new TextCellInfoDescription());
            a.ad("TextCellInfo", TextCellInfoDescriptionMetadata.a);
        }
    }
    TextCellInfoDescriptionMetadata.$t = markType(TextCellInfoDescriptionMetadata, 'TextCellInfoDescriptionMetadata');
    TextCellInfoDescriptionMetadata.a = null;
    return TextCellInfoDescriptionMetadata;
})();
